//标准化输出

import { getUnitMaxOccNum, separateDataAndUint, unifiedMaxAndMinValueAndStep } from "./privateTools";



/**
 * getStringOutData  获取文字列表返回结果
 * @param title  数据标题
 * @param valueList 数据体 格式:["txt...", "str..."]
 * @returns {title, data:[string...]}
 */
export function getStringOutData(title, valueList) {
    let result = { title, data:[] };
    valueList.forEach( str => {
        result.data.push(str);
    });
    return result;
}

/**
 * getChartData  获取图表列表返回结果
 * @param title 数据标题
 * @param data  数据体  格式：{"图表名称":{unit:"", dataInfo:[{key:"数据key", value:"数据值"}, {key:"数据key", value:"数据值"} ] } }
 * @param haveMoreY 是否有多个y轴  默认false
 * @returns 
 */
export function getChartData(title, data) {
    let result = { title, dataList:[] };

    for (let chartName in data) {
        let { unit, dataInfo } = data[chartName];

        let addData:any = { title: chartName };

        let max = 0;
        let min = new Date().valueOf();
        let total = 0;
        let thisUnitStats = {};
        let dataList = [];
        for (let i = 0; i < dataInfo.length; i++) {
            let { key, value } = dataInfo[i];
            let { dataNum, dataUnit } = separateDataAndUint(value);
            min = Math.min(min, dataNum);
            max = Math.max(max, dataNum);
            thisUnitStats[dataUnit] = thisUnitStats[dataUnit] ? thisUnitStats[dataUnit] + 1 : 1;
            total += dataNum;

            dataList.push({key, value:dataNum, unit:dataUnit});
        }
        let statsUnit = getUnitMaxOccNum(thisUnitStats);
        let thisChartUnit = unit || statsUnit || "";

        addData["unit"] = thisChartUnit;
        addData["total"] = total;
        let {maxNumber, minNumber, stepNumber} = unifiedMaxAndMinValueAndStep(max, min);
        addData["yMinValue"] = minNumber;
        addData["yMaxValue"] = maxNumber;
        addData["yStepValue"] = stepNumber;
        addData["dataList"] = dataList;

        result.dataList.push(addData);
    }
}





